## How to use Cybot Framework
   
 [Another examples](https://github.com/francis-taylor/Cybot/blob/master/exemplo/README.md)
 [Avaliable methods](https://github.com/francis-taylor/Cybot/blob/master/exemplo/README.md)
  
## Thanks

 [WebWhatsApi](https://webwhatsapi.readthedocs.io/en/)
